==> core-1.0.1.tgz: package/lib/class-names/chip-class-names.js <==
import { getHostClassNames } from './class-names';
import { validateUiComponentProps } from '../ui-component-props/ui-component-props';
export const chipLayoutClassNamesConfig = {
    prefix: 'cck-chip',
    elements: {
        host: {
            name: 'Host Element',
            selectors: [
                'cck-chip'
            ],
            description: 'It will add to the host element of Chip component.'
        },
        disabled: {
            name: 'Host Element',
            selectors: [
                'cck-chip--disabled'
            ],
            description: 'Applied to the host element of the Chip component, when the the chip is disabled'
        },
        removable: {
            name: 'Host Element',
            selectors: [
                'cck-chip--removable'
            ],
            description: 'Applied to the host element of the Chip component, when the the chip is removable'
        },
        contentWrapper: {
            name: 'Wrapper of content',
            selectors: [
                'cck-chip__content-wrapper'
            ],
            description: 'It will add to the wrapper of content element.'
        },
        removeIconWrapper: {
            name: 'Wrapper of remove icon',
            selectors: [
                'cck-chip__remove-icon-wrapper'
            ],
            description: 'It will add to the wrapper of remove icon element.'
        }
    }
};
export function getChipClassNames(componentProps, uiComponentsConfig) {
    const options = {
        componentName: 'chip',
        componentProps,
        uiComponentsConfig
    };
    validateUiComponentProps(options);
    return {
        host: [
            ...chipLayoutClassNamesConfig.elements.host.selectors,
            ...getHostClassNames(chipLayoutClassNamesConfig.prefix, options)
        ],
        disabled: [
            ...chipLayoutClassNamesConfig.elements.disabled.selectors
        ],
        removable: [
            ...chipLayoutClassNamesConfig.elements.removable.selectors
        ],
        contentWrapper: [
            ...chipLayoutClassNamesConfig.elements.contentWrapper.selectors
        ],
        removeIconWrapper: [
            ...chipLayoutClassNamesConfig.elements.removeIconWrapper.selectors
        ]
    };
}

==> core-1.1.0.tgz: package/lib/class-names/chip-class-names.js <==
import { getHostClassNames } from './class-names';
import { validateUiBaseComponentProps } from '../ui-component-props/ui-component-props';
export const chipLayoutClassNamesConfig = {
    prefix: 'cck-chip',
    elements: {
        host: {
            name: 'Host Element',
            selectors: [
                'cck-chip'
            ],
            description: 'It will add to the host element of Chip component.'
        },
        disabled: {
            name: 'Host Element',
            selectors: [
                'cck-chip--disabled'
            ],
            description: 'Applied to the host element of the Chip component, when the the chip is disabled'
        },
        removable: {
            name: 'Host Element',
            selectors: [
                'cck-chip--removable'
            ],
            description: 'Applied to the host element of the Chip component, when the the chip is removable'
        },
        contentWrapper: {
            name: 'Wrapper of content',
            selectors: [
                'cck-chip__content-wrapper'
            ],
            description: 'It will add to the wrapper of content element.'
        },
        removeIconWrapper: {
            name: 'Wrapper of remove icon',
            selectors: [
                'cck-chip__remove-icon-wrapper'
            ],
            description: 'It will add to the wrapper of remove icon element.'
        }
    }
};
export function getChipClassNames(componentProps, themeConfig) {
    const options = {
        componentName: 'chip',
        componentProps,
        themeConfig
    };
    validateUiBaseComponentProps(options);
    return {
        host: [
            ...chipLayoutClassNamesConfig.elements.host.selectors,
            ...getHostClassNames(chipLayoutClassNamesConfig.prefix, options)
        ].join(' '),
        disabled: [
            ...chipLayoutClassNamesConfig.elements.disabled.selectors
        ].join(' '),
        removable: [
            ...chipLayoutClassNamesConfig.elements.removable.selectors
        ].join(' '),
        contentWrapper: [
            ...chipLayoutClassNamesConfig.elements.contentWrapper.selectors
        ].join(' '),
        removeIconWrapper: [
            ...chipLayoutClassNamesConfig.elements.removeIconWrapper.selectors
        ].join(' ')
    };
}
